﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using Telerik.Web.UI.Widgets;


public partial class Tickets_Default : System.Web.UI.Page
{


    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);

        RadFileExplorer1.TreeView.NodeCreated += new RadTreeViewEventHandler(TreeView_NodeCreated);
        RadFileExplorer1.ExplorerPopulated += new RadFileExplorerGridEventHandler(RadFileExplorer1_ExplorerPopulated);
        RadFileExplorer1.TreeView.PreRender += new EventHandler(TreeView_PreRender);

        RadFileExplorer1.TreeView.NodeDataBound +=new RadTreeViewEventHandler(TreeView_NodeDataBound);
    }

    void TreeView_PreRender(object sender, EventArgs e)
    {
        RadTreeView treeView = sender as RadTreeView;
        foreach (RadTreeNode node in treeView.Nodes)
        {
            string[] textSplitted = node.Text.Split(new string[] { CustomColumnsContentProvider.CustomAttributeSeparator }, StringSplitOptions.RemoveEmptyEntries);
            node.Text = textSplitted[0];
        }
    }

    void RadFileExplorer1_ExplorerPopulated(object sender, RadFileExplorerPopulatedEventArgs e)
    {
        if (e.ControlName == "grid")
        {
            e.List = e.List.Select(it =>
                      {
                          DirectoryItem dirItem = it as DirectoryItem;
                          if (dirItem != null)
                          {
                              //  node.Text "DirName$#$CustomAttributeValue"
                              string[] textSplitted = dirItem.Name.Split(new string[] { CustomColumnsContentProvider.CustomAttributeSeparator }, StringSplitOptions.RemoveEmptyEntries);

                              if (textSplitted.Length == 2)
                              {
                                  string folderName = textSplitted[0];

                                  return new DirectoryItem(folderName, dirItem.Location, dirItem.FullPath, dirItem.Tag, dirItem.Permissions, dirItem.Files, dirItem.Directories);
                              }

                              return dirItem;
                          }
                          return it;
                      }).ToList();
        }
    }

    void TreeView_NodeCreated(object sender, RadTreeNodeEventArgs e)
    {
        AddFileExplorerItemAttributes(e.Node);
    }

    void TreeView_NodeDataBound(object sender, RadTreeNodeEventArgs e)
    {
        //
    }


    private void AddFileExplorerItemAttributes(RadTreeNode node)
    {
        //  node.Text "DirName$#$CustomAttributeValue"
        string[] textSplitted = node.Text.Split(new string[] { CustomColumnsContentProvider.CustomAttributeSeparator }, StringSplitOptions.RemoveEmptyEntries);

        if (textSplitted.Length == 2)
        {
            string folderName = textSplitted[0];
            string customAttributeValue = textSplitted[1];

            node.Attributes.Add("customAttribute", customAttributeValue);
            node.Text = folderName;
        }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        RadFileExplorer1.Configuration.ContentProviderTypeName = typeof(CustomColumnsContentProvider).AssemblyQualifiedName;
    }


    public class CustomColumnsContentProvider : FileSystemContentProvider
    {
        public CustomColumnsContentProvider(HttpContext context, string[] searchPatterns, string[] viewPaths, string[] uploadPaths, string[] deletePaths, string selectedUrl, string selectedItemTag)
            : base(context, searchPatterns, viewPaths, uploadPaths, deletePaths, selectedUrl, selectedItemTag)
        {
            // Declaring a constructor is required when creating a custom content provider class
        }

        public static string CustomAttributeSeparator
        {
            get
            {
                return "$#$";
            }
        }

        public override DirectoryItem ResolveRootDirectoryAsTree(string path)
        {
            DirectoryItem oldItem = base.ResolveRootDirectoryAsTree(path);

            List<DirectoryItem> subDirs = new List<DirectoryItem>();

            foreach (DirectoryItem dirItem in oldItem.Directories)//change the name of the folder to pass the custom attribute value
            {
                //"DirName$#$CustomAttributeValue"
                DirectoryItem newSubDir = new DirectoryItem(string.Format("{0}{1}{2}", dirItem.Name, CustomAttributeSeparator, "DSFDFD"), dirItem.Location, dirItem.FullPath, dirItem.Tag, dirItem.Permissions, dirItem.Files, dirItem.Directories);
                subDirs.Add(newSubDir);
            }

            DirectoryItem newDirItem = new DirectoryItem(string.Format("{0}{1}{2}", oldItem.Name, CustomAttributeSeparator, "DSFDFD"), oldItem.Location, oldItem.FullPath, oldItem.Tag, oldItem.Permissions, oldItem.Files, subDirs.ToArray());

            return newDirItem;
        }
        public override DirectoryItem ResolveDirectory(string path)
        {
            DirectoryItem oldItem = base.ResolveDirectory(path);

            List<DirectoryItem> subDirs = new List<DirectoryItem>();

            foreach (DirectoryItem dirItem in oldItem.Directories)//change the name of the folder to pass the custom attribute value
            {
                //"DirName$#$CustomAttributeValue"
                DirectoryItem newSubDir = new DirectoryItem(string.Format("{0}{1}{2}", dirItem.Name, CustomAttributeSeparator, "DSFDFD"), dirItem.Location, dirItem.FullPath, dirItem.Tag, dirItem.Permissions, dirItem.Files, dirItem.Directories);
                subDirs.Add(newSubDir);
            }

            DirectoryItem newDirItem = new DirectoryItem(string.Format("{0}{1}{2}", oldItem.Name, CustomAttributeSeparator, "DSFDFD"), oldItem.Location, oldItem.FullPath, oldItem.Tag, oldItem.Permissions, oldItem.Files, subDirs.ToArray());

            return newDirItem;
        }
    }

}

